@@ -206,14 +206,13 @@ class Container:
             Reload current view
         """
         values_two = self._list_two.get_selected_ids()
-        if not values_two:
-            values_one = self._list_one.get_selected_ids()
-            if not values_one:
-                values_one = [Type.POPULARS]
-            self._list_one.select_ids([])
-            self._list_one.clear()
-            self._update_list_one(None)
-            self._list_one.select_ids(values_one)
+        values_one = self._list_one.get_selected_ids()
+        if not values_one:
+            values_one = [Type.POPULARS]
+        self._list_one.select_ids([])
+        self._list_one.clear()
+        self._update_list_one(None)
+        self._list_one.select_ids(values_one)
         if self._list_two.is_visible():
             self._list_two.select_ids([])
             self._list_two.clear()
@@ -469,11 +468,13 @@ class Container:
         def setup(artists, compilations):
             if selection_list == self._list_one:
                 items = self._get_headers()
-                items.append((Type.SEPARATOR, ''))
+                if not compilations:
+                    items.append((Type.SEPARATOR, ''))
             else:
                 items = []
             if compilations:
                 items.append((Type.COMPILATIONS, _("Compilations")))
+                items.append((Type.SEPARATOR, ''))
             items += artists
             selection_list.mark_as_artists(True)
             if update:
@@ -685,8 +686,8 @@ class Container:
         selected_ids = self._list_one.get_selected_ids()
         if not selected_ids:
             return
+        self._list_two.clear()
         if selected_ids[0] == Type.PLAYLISTS:
-            self._list_two.clear()
             self._list_two.show()
             if not self._list_two.will_be_selected():
                 self._update_view_playlists()
@@ -712,7 +713,6 @@ class Container:
             else:
                 self._update_view_artists([], selected_ids)
         else:
-            self._list_two.clear()
             self._setup_list_artists(self._list_two, selected_ids, False)
             self._list_two.show()
             if not self._list_two.will_be_selected():
