@@ -117,6 +117,7 @@ class AlbumRow(Gtk.ListBoxRow):
         grid.attach(vgrid, 1, 1, 1, 1)
         row_widget.add(grid)
         self.add(row_widget)
+        self.get_style_context().add_class('trackrow')
         self.show_play_indicator(self._album.id ==
                                  Lp().player.current_track.album.id)
         self.show_all()
@@ -131,7 +132,6 @@ class AlbumRow(Gtk.ListBoxRow):
         self.connect('drag-data-received', self._on_drag_data_received)
         self.connect('drag-motion', self._on_drag_motion)
         self.connect('drag-leave', self._on_drag_leave)
-        self.get_style_context().add_class('trackrow')
 
     def do_get_preferred_height(self):
         """
@@ -503,15 +503,16 @@ class AlbumsPopover(Gtk.Popover):
             Init popover
         """
         Gtk.Popover.__init__(self)
-        self.set_position(Gtk.PositionType.BOTTOM)
         view = AlbumsView()
         view.show()
+        self.set_position(Gtk.PositionType.BOTTOM)
+        self.connect('map', self._on_map)
         self.add(view)
 
-    def do_show(self):
+    def _on_map(self, widget):
         """
-            Set widget size
+            Resize
+            @param widget as Gtk.Widget
         """
         height = Lp().window.get_size()[1]
         self.set_size_request(400, height*0.7)
-        Gtk.Popover.do_show(self)
