@@ -150,6 +150,19 @@ class LazyLoadingView(View):
         self._lazy_queue.append(row)
 
     def lazy_loading(self, widgets=[], scroll_value=0):
+        """
+            Load the view in a lazy way:
+                - widgets first
+                - _waiting_init then
+            @param widgets as [AlbumSimpleWidgets]
+            @param scroll_value as float
+        """
+        GLib.idle_add(self._lazy_loading, widgets, scroll_value)
+
+#######################
+# PRIVATE             #
+#######################
+    def _lazy_loading(self, widgets=[], scroll_value=0):
         """
             Load the view in a lazy way:
                 - widgets first
@@ -172,9 +185,6 @@ class LazyLoadingView(View):
             else:
                 GLib.idle_add(self.lazy_loading, widgets, scroll_value)
 
-#######################
-# PRIVATE             #
-#######################
     def _is_visible(self, widget):
         """
             Is widget visible in scrolled
