@@ -14,6 +14,7 @@ from gi.repository import Gtk, Gdk, Pango
 
 from gettext import gettext as _
 from math import pi
+from cgi import escape
 
 from lollypop.define import Lp, ArtSize
 from lollypop.objects import Track, Album
@@ -49,7 +50,6 @@ class ArtistView(ArtistAlbumsView):
         self._jump_button.set_tooltip_text(_("Go to current track"))
         self._add_button = builder.get_object('add-button')
         self._grid = builder.get_object('header-grid')
-        self._spinner = builder.get_object('spinner')
         header = builder.get_object('header')
         header.set_property('valign', Gtk.Align.START)
         self._overlay.add_overlay(header)
@@ -63,7 +63,14 @@ class ArtistView(ArtistAlbumsView):
         artists = []
         for artist_id in artist_ids:
             artists.append(Lp().artists.get_name(artist_id))
-        self._label.set_label(", ".join(artists))
+        if Lp().settings.get_value('artist-artwork'):
+            self._label.set_markup("<span size='x-large' weight='bold'>" +
+                                   escape(", ".join(artists)) +
+                                   "</span>")
+        else:
+            self._label.set_markup("<span size='large' weight='bold'>" +
+                                   escape(", ".join(artists)) +
+                                   "</span>")
 
     def jump_to_current(self):
         """
@@ -214,15 +221,16 @@ class ArtistView(ArtistAlbumsView):
         """
         ArtistAlbumsView._on_value_changed(self, adj)
         if adj.get_value() == adj.get_lower():
-            if Lp().settings.get_value('artist-artwork'):
+            if self._artwork.get_pixbuf() is not None:
                 self._artwork.show()
                 self._artwork_box.show()
             self._grid.get_style_context().remove_class('header-borders')
             self._grid.get_style_context().add_class('header')
             self._grid.set_property('valign', Gtk.Align.CENTER)
         else:
-            self._artwork.hide()
-            self._artwork_box.hide()
+            if self._artwork.get_pixbuf() is not None:
+                self._artwork.hide()
+                self._artwork_box.hide()
             self._grid.get_style_context().add_class('header-borders')
             self._grid.get_style_context().remove_class('header')
             self._grid.set_property('valign', Gtk.Align.START)
@@ -235,8 +243,6 @@ class ArtistView(ArtistAlbumsView):
             @param scroll value as float
         """
         self._update_jump_button()
-        self._spinner.stop()
-        self._spinner.hide()
         ArtistAlbumsView._on_populated(self, widget, widgets, scroll_value)
 
     def _on_current_changed(self, player):
@@ -291,7 +297,7 @@ class ArtistView(ArtistAlbumsView):
         if Lp().player.is_party():
             Lp().player.set_party(False)
         album_id = Lp().albums.get_ids(self._artist_ids, self._genre_ids)[0]
-        track = Track(Album(album_id).tracks_ids[0])
+        track = Track(Album(album_id).track_ids[0])
         Lp().player.load(track)
         Lp().player.set_albums(track.id, self._artist_ids,
                                self._genre_ids)
