@@ -313,7 +313,7 @@ class AlbumWidget:
         self._show_append(False)
         if Lp().player.is_party():
             Lp().player.set_party(False)
-        track = Track(self._album.tracks_ids[0])
+        track = Track(self._album.track_ids[0])
         Lp().player.load(track)
         Lp().player.set_albums(track.id, self._filter_ids,
                                self._album.genre_ids)
@@ -614,7 +614,6 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         self._widget = builder.get_object('widget')
         self._overlay = builder.get_object('overlay')
         self._play_button = builder.get_object('play-button')
-        self._play_all_button = builder.get_object('playall-button')
         self._artwork_button = builder.get_object('artwork-button')
         self._action_button = builder.get_object('action-button')
         self._action_event = builder.get_object('action-event')
@@ -663,6 +662,8 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         self._box = Gtk.Grid()
         self._box.set_column_homogeneous(True)
         self._box.set_property('valign', Gtk.Align.START)
+        self._box.set_sensitive(False)
+        self._box.set_opacity(0)
         self._box.show()
         builder.get_object('albuminfo').add(self._box)
 
@@ -695,12 +696,6 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         else:
             self.connect('map', self._on_map)
 
-    def disable_play_all(self):
-        """
-            Disable play all albums button
-        """
-        self._play_all_button = None
-
     def update_playing_indicator(self):
         """
             Update playing indicator
@@ -853,6 +848,8 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         if not tracks:
             if widget == self._tracks_right:
                 self.emit('populated')
+                self._box.set_sensitive(True)
+                self._box.set_opacity(1)
             else:
                 self._locked_widget_right = False
             return
@@ -917,7 +914,7 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
                 show_label = len(self._album.discs) > 1
                 if show_label:
                     label = Gtk.Label()
-                    disc_text = _("Disc %s" % disc.number)
+                    disc_text = _("Disc %s") % disc.number
                     disc_names = self._album.disc_names(disc.number)
                     if disc_names:
                         disc_text += ": " + ", ".join(disc_names)
