@@ -608,10 +608,10 @@ class PlaylistsManagerWidget(Gtk.Bin):
         def set(playlist_id, add):
             tracks = []
             if self._is_album:
-                tracks_ids = Lp().albums.get_tracks(self._object_id,
-                                                    self._genre_ids,
-                                                    self._artist_ids)
-                for track_id in tracks_ids:
+                track_ids = Lp().albums.get_tracks(self._object_id,
+                                                   self._genre_ids,
+                                                   self._artist_ids)
+                for track_id in track_ids:
                     tracks.append(Track(track_id))
             else:
                 tracks = [Track(self._object_id)]
@@ -649,6 +649,7 @@ class PlaylistsManagerWidget(Gtk.Bin):
             @param editable as Gtk.CellEditable
             @param path as str representation of Gtk.TreePath
         """
+        # FIXME Not needed with GTK >= 3.18
         Lp().window.enable_global_shorcuts(False)
 
     def _on_playlist_editing_cancel(self, widget):
@@ -656,6 +657,7 @@ class PlaylistsManagerWidget(Gtk.Bin):
             Enable global shortcuts
             @param widget as cell renderer
         """
+        # FIXME Not needed with GTK >= 3.18
         Lp().window.enable_global_shorcuts(True)
 
 
