@@ -35,6 +35,7 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
         self.get_style_context().add_class('loading')
         self._name = name
         self._cover = None
+        self._lock_overlay = False
         self._radios_manager = radios_manager
 
     def populate(self):
@@ -66,8 +67,8 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
         grid.add(self._overlay)
         grid.add(self._title_label)
         self._widget.add(grid)
-        self._widget.set_property('halign', Gtk.Align.CENTER)
-        self._widget.set_property('valign', Gtk.Align.CENTER)
+        self.set_property('halign', Gtk.Align.CENTER)
+        self.set_property('valign', Gtk.Align.CENTER)
         self.add(self._widget)
         self.set_cover()
         self.update_state()
@@ -90,11 +91,9 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
             Return preferred width
             @return (int, int)
         """
-        if self._cover is not None:
-            widths = self._cover.get_preferred_width()
-            return (widths[0] + 8, widths[1] + 8)
-        else:
-            return (0, 0)
+        # Padding: 3px, border: 1px + spacing
+        width = ArtSize.BIG + 16
+        return (width, width)
 
     def set_name(self, name):
         """
