@@ -15,7 +15,7 @@ from gi.repository import Gtk, Gio, GLib
 from lollypop.container import Container
 from lollypop.define import Lp, NextContext, Shuffle, WindowSize
 from lollypop.toolbar import Toolbar
-from lollypop.utils import is_unity
+from lollypop.utils import is_unity, set_loved, is_loved
 from lollypop.miniplayer import MiniPlayer
 
 
@@ -110,6 +110,8 @@ class Window(Gtk.ApplicationWindow, Container):
                                             ["<Control>n"])
             self._app.set_accels_for_action("app.player::prev",
                                             ["p"])
+            self._app.set_accels_for_action("app.player::loved",
+                                            ["l"])
         else:
             self._app.set_accels_for_action("app.seek(10)", [None])
             self._app.set_accels_for_action("app.seek(20)", [None])
@@ -124,6 +126,7 @@ class Window(Gtk.ApplicationWindow, Container):
             self._app.set_accels_for_action("app.player::next", [None])
             self._app.set_accels_for_action("app.player::next_album", [None])
             self._app.set_accels_for_action("app.player::prev", [None])
+            self._app.set_accels_for_action("app.player::loved", [None])
 
     def setup_window(self):
         """
@@ -316,7 +319,8 @@ class Window(Gtk.ApplicationWindow, Container):
             vgrid.add(self._toolbar)
         else:
             self.set_titlebar(self._toolbar)
-            self._toolbar.set_show_close_button(True)
+            self._toolbar.set_show_close_button(
+                                    not Lp().settings.get_value('disable-csd'))
         vgrid.add(self._main_stack)
         vgrid.add(self._subtoolbar)
         self.add(vgrid)
@@ -439,6 +443,19 @@ class Window(Gtk.ApplicationWindow, Container):
                 Lp().player.next()
         elif string == "prev":
             Lp().player.prev()
+        elif string == "loved":
+            if Lp().player.current_track.id is not None:
+                isloved = is_loved(Lp().player.current_track.id)
+                set_loved(Lp().player.current_track.id, not isloved)
+                if Lp().notify is not None:
+                    if isloved:
+                        heart = "♡"
+                    else:
+                        heart = "❤"
+                    Lp().notify.send("%s - %s: %s" % (
+                                ", ".join(Lp().player.current_track.artists),
+                                Lp().player.current_track.name,
+                                heart))
 
     def _on_realize(self, widget):
         """
